
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7094241.svg)](https://doi.org/10.5281/zenodo.7094241)
[![PyPI version](https://badge.fury.io/py/rlmolecule.svg)](https://badge.fury.io/py/rlmolecule)

# rlmolecule

## About

A library for general-purpose material and molecular optimization using
AlphaZero-style reinforcement learning.

Code under development as part of the End-to-End Optimization for Battery
Materials and Molecules by Combining Graph Neural Networks and Reinforcement
Learning project at the National Renewable Energy Laboratory (NREL), Colorado
School of Mines (CSU), and Colorado State University (CSU). Funding provided by
the Advanced Research Projects Agency–Energy (ARPA-E)'s
[DIFFERENTIATE program](https://arpa-e.energy.gov/technologies/programs/differentiate).

For more information, see our publication:

S. V., S. S., Law, J. N., Tripp, C. E., Duplyakin, D., Skordilis, E., Biagioni,
D., Paton, R. S., & St. John, P. C. (2022). Multi-objective goal-directed
optimization of de novo stable organic radicals for aqueous redox flow
batteries. Nature Machine Intelligence.
[10.1038/s42256-022-00506-3](https://doi.org/10.1038/s42256-022-00506-3)

## Installation

`pip install rlmolecule`

## Running in AWS Ray clusters 

Refer to the instructions available in: `devtools/aws/README.md`
